==> rn-shiki-0.0.37-103.tgz: package/src/utils/style.ts <==
import type { RawThemeSetting, ThemeRegistrationAny } from '@shikijs/types'
import type { TextStyle } from 'react-native'
import transform, { type StyleTuple } from 'css-to-react-native'

export interface ShikiStyleSheet {
  [key: string]: TextStyle
}

const ALLOWED_STYLE_PROPERTIES: Record<string, boolean> = {
  color: true,
  background: true,
  backgroundColor: true,
  fontWeight: true,
  fontStyle: true,
  textDecoration: true,
}

function parseFontStyle(fontStyle?: string): { fontStyle?: 'italic', fontWeight?: 'bold' } {
  if (!fontStyle)
    return {}

  const styles: { fontStyle?: 'italic', fontWeight?: 'bold' } = {}
  if (fontStyle.includes('italic'))
    styles.fontStyle = 'italic'
  if (fontStyle.includes('bold'))
    styles.fontWeight = 'bold'
  return styles
}

export function getStylesFromShikiTheme(theme: ThemeRegistrationAny): ShikiStyleSheet {
  const styles: ShikiStyleSheet = {
    root: {
      backgroundColor: theme.bg || theme.colors?.['editor.background'] || '#000000',
      color: theme.fg || theme.colors?.['editor.foreground'] || '#ffffff',
    },
  }

  // Convert theme settings to styles
  theme.settings?.forEach((setting: RawThemeSetting) => {
    if (setting.scope && setting.settings) {
      const scopes = Array.isArray(setting.scope) ? setting.scope : [setting.scope]

      const fontStyles = parseFontStyle(setting.settings.fontStyle)

      scopes.forEach((scope) => {
        styles[scope] = cleanStyle({
          color: setting.settings.foreground,
          backgroundColor: setting.settings.background,
          ...fontStyles,
        })
      })
    }
  })

  return styles
}

export function cleanStyle(style: Record<string, any>): TextStyle {
  const styles = Object.entries(style)
    .filter(([key, value]) => ALLOWED_STYLE_PROPERTIES[key] && value !== undefined)
    .map<StyleTuple>(([key, value]) => [key, value])

  return transform(styles)
}

==> rn-shiki-0.0.37-112.tgz: package/src/utils/style.ts <==
import type { ThemeRegistrationAny } from '@shikijs/types'
import type { TextStyle } from 'react-native'
import transform, { type StyleTuple } from 'css-to-react-native'

export interface ShikiStyleSheet {
  [key: string]: TextStyle
}

const ALLOWED_STYLE_PROPERTIES: Record<string, boolean> = {
  color: true,
  background: true,
  backgroundColor: true,
  fontWeight: true,
  fontStyle: true,
  textDecoration: true,
}

function parseFontStyle(fontStyle?: string): { fontStyle?: 'italic', fontWeight?: 'bold' } {
  if (!fontStyle)
    return {}

  const styles: { fontStyle?: 'italic', fontWeight?: 'bold' } = {}
  if (fontStyle.includes('italic'))
    styles.fontStyle = 'italic'
  if (fontStyle.includes('bold'))
    styles.fontWeight = 'bold'
  return styles
}

export function getStylesFromShikiTheme(theme: ThemeRegistrationAny): ShikiStyleSheet {
  console.log('Processing theme:', {
    name: theme.name,
    settingsCount: theme.settings?.length,
    hasColors: !!theme.colors,
  })

  const styles: ShikiStyleSheet = {
    root: {
      backgroundColor: theme.bg || theme.colors?.['editor.background'] || '#000000',
      color: theme.fg || theme.colors?.['editor.foreground'] || '#ffffff',
    },
  }

  console.log('Root styles:', styles.root)

  // Convert theme settings to styles
  theme.settings?.forEach((setting, index) => {
    if (setting.scope && setting.settings) {
      const scopes = Array.isArray(setting.scope) ? setting.scope : [setting.scope]

      console.log('Processing setting:', {
        index,
        scopes,
        settings: setting.settings,
      })

      const fontStyles = parseFontStyle(setting.settings.fontStyle)

      scopes.forEach((scope) => {
        const style = cleanStyle({
          color: setting.settings.foreground,
          backgroundColor: setting.settings.background,
          ...fontStyles,
        })

        console.log('Generated style for scope:', {
          scope,
          style,
        })

        styles[scope] = style
      })
    }
  })

  return styles
}

export function cleanStyle(style: Record<string, any>): TextStyle {
  const styles = Object.entries(style)
    .filter(([key, value]) => ALLOWED_STYLE_PROPERTIES[key] && value !== undefined)
    .map<StyleTuple>(([key, value]) => [key, value])

  return transform(styles)
}
